@@ -5,9 +5,9 @@
 # This program is free software under the GPL (>=v2)
 # Read the file COPYING coming with Thuban for details.
 
-__version__ = "$Revision: 2721 $"
+__version__ = "$Revision: 2817 $"
 # $Source$
-# $Id: maplegend.py 2721 2007-01-13 15:11:42Z dpinte $
+# $Id: maplegend.py 2817 2008-01-27 00:01:32Z bernhard $
 
 
 """
@@ -15,8 +15,9 @@ Write a basic map legend in svg format.
 """
 
 
-# Needed wx.-toolkit classes
-import wx
+# Needed wx-toolkit classes
+from wx import FileDialog, SAVE, OVERWRITE_PROMPT, \
+        ID_OK, Rect
 
 # We need os.path
 import os
@@ -31,6 +32,8 @@ from Thuban.Model.color import Transparent, Color, Black
 from Thuban.Model.data import SHAPETYPE_POLYGON, SHAPETYPE_ARC, \
     SHAPETYPE_POINT, RAW_SHAPEFILE
 
+from Thuban.UI import internal_from_wxstring
+
 # Import SVG related classes
 from svgmapwriter import SVGRenderer, VirtualDC, TRANSPARENT_PEN, \
         TRANSPARENT_BRUSH, SOLID, Pen, Brush, Point
@@ -82,7 +85,7 @@ class SVGMapLegend(SVGRenderer):
                         shapeType = l.ShapeType()
                         for g in clazz:
                             if g.IsVisible():
-                                self.Draw(dc, wx.Rect(posx+dx, 
+                                self.Draw(dc, Rect(posx+dx, 
                                         posy-iconheight+2,
                                         iconwidth, iconheight),
                                         g.GetProperties(), shapeType)
@@ -131,13 +134,13 @@ def write_legend(context):
     else:
         export_path="."
     # Get the file the session shall be written to
-    dlg = wx.FileDialog(canvas, _("Write SVG"), export_path, "", 
+    dlg = FileDialog(canvas, _("Write SVG"), export_path, "", 
             "Scalable Vector Graphics (*.svg)|*.svg", 
-            wx.SAVE|wx.OVERWRITE_PROMPT)
+            SAVE|OVERWRITE_PROMPT)
     #
     response = dlg.ShowModal()
-    if response == wx.ID_OK:
-        file = dlg.GetPath()
+    if response == ID_OK:
+        file = internal_from_wxstring(dlg.GetPath())
     else: # Do nothing if choice was interrupted.
         return 0
         
