@@ -1,4 +1,4 @@
-# -*- coding:latin1 -*-
+# -*- coding:iso-8859-15 -*-
 # Copyright (C) 2004 by Intevation GmbH
 # Authors:
 # Jan Schngel <jschuengel@intevation.de>
@@ -11,9 +11,9 @@ This modul extend Thuban with the possibility to handle
 UMN MapServer mapfiles.
 """
 
-__version__ = "$Revision: 2719 $"
+__version__ = "$Revision: 2858 $"
 # $Source$
-# $Id: mf_handle.py 2719 2007-01-08 16:30:29Z dpinte $
+# $Id: mf_handle.py 2858 2008-07-29 06:17:34Z elachuni $
 
 
 # ###################################
@@ -27,7 +27,8 @@ import os, sys
 # mapscript
 from mapscript import mapObj, layerObj
 
-# wx.Python support
+# wxPython support
+# TODO: explicitly use from .. import
 import wx
 from wx import grid
 
@@ -114,7 +115,7 @@ class Map_Dialog(wx.Dialog):
         box_imagetype = wx.StaticBoxSizer(box_imagetypeStatic, wx.VERTICAL)
         self.choice_imgtype = wx.Choice(self, 8060, (80, 50), 
                                         choices = umn_outputformats)
-        EVT_CHOICE(self, 8060, self.EvtChoiceBox)
+        wx.EVT_CHOICE(self, 8060, self.EvtChoiceBox)
         self.choice_imgtype.SetStringSelection(umn_imagetype)
         box_imagetype.Add(self.choice_imgtype,0, wx.EXPAND, wx.ALL, 5)    
         
@@ -146,7 +147,7 @@ class Map_Dialog(wx.Dialog):
         # color change button, opens a new color dialog
         button = wx.Button(self, ID_COLOR_CHANGE, _("Change Color"))
         button.SetFocus()
-        EVT_BUTTON(self, ID_COLOR_CHANGE, self.OnChangeColor)
+        wx.EVT_BUTTON(self, ID_COLOR_CHANGE, self.OnChangeColor)
         box_color.Add(button, 1, wx.EXPAND|wx.ALL, 5)
         
         # status
@@ -163,8 +164,8 @@ class Map_Dialog(wx.Dialog):
         button = wx.Button(self, wx.ID_CANCEL, _("Cancel"))
         box_buttons.Add(button, 0, wx.ALL, 5)
         #button functions
-        EVT_BUTTON(self, wx.ID_OK, self.OnOK)
-        EVT_BUTTON(self, wx.ID_CANCEL, self.OnCancel)
+        wx.EVT_BUTTON(self, wx.ID_OK, self.OnOK)
+        wx.EVT_BUTTON(self, wx.ID_CANCEL, self.OnCancel)
         
         #add all boxes to the box top
         top = wx.BoxSizer(wx.VERTICAL)
@@ -213,8 +214,15 @@ class Map_Dialog(wx.Dialog):
         self.Show(False)
 
     def OnOK(self, event):
-        self.tb_map_umn.set_size(int(self.text_width.GetValue()), 
-                                 int(self.text_height.GetValue()))
+        try:
+            width = int(self.text_width.GetValue())
+            height = int(self.text_height.GetValue())
+        except ValueError, e:
+            dlg = wx.MessageDialog (self, "Width / Height: " + str(e),
+                                    "Warning", wx.OK)
+            dlg.ShowModal()
+            return
+        self.tb_map_umn.set_size(width, height)
         self.tb_map_umn.set_units(self.choice_units.GetStringSelection())
         if self.choice_status.GetStringSelection() == "True":
             self.tb_map_umn.set_status(True)
@@ -279,8 +287,8 @@ class Web_Dialog(wx.Dialog):
         button = wx.Button(self, wx.ID_CANCEL, _("Cancel"))
         box_buttons.Add(button, 0, wx.ALL, 5)
         #set the button funcitons
-        EVT_BUTTON(self, wx.ID_OK, self.OnOK)
-        EVT_BUTTON(self, wx.ID_CANCEL, self.OnCancel)      
+        wx.EVT_BUTTON(self, wx.ID_OK, self.OnOK)
+        wx.EVT_BUTTON(self, wx.ID_CANCEL, self.OnCancel)      
       
         # compose the final dialog
         top = wx.BoxSizer(wx.VERTICAL)
@@ -346,7 +354,7 @@ class Layer_Dialog(wx.Dialog):
  
         # metadata button
         metadata_button = wx.Button(self, ID_METADATA_CHANGE, _("Edit Metadata"))
-        EVT_BUTTON(self, ID_METADATA_CHANGE, self.OnChangeMetadata)
+        wx.EVT_BUTTON(self, ID_METADATA_CHANGE, self.OnChangeMetadata)
         
         # Group 
         box_group = wx.BoxSizer(wx.HORIZONTAL)
@@ -369,8 +377,8 @@ class Layer_Dialog(wx.Dialog):
         button = wx.Button(self, wx.ID_CANCEL, _("Cancel"))
         box_buttons.Add(button, 0, wx.ALL, 5)
         #set the button funcitons
-        EVT_BUTTON(self, wx.ID_OK, self.OnOK)
-        EVT_BUTTON(self, wx.ID_CANCEL, self.OnCancel)      
+        wx.EVT_BUTTON(self, wx.ID_OK, self.OnOK)
+        wx.EVT_BUTTON(self, wx.ID_CANCEL, self.OnCancel)      
       
         # compose the final dialog
         top = wx.BoxSizer(wx.VERTICAL)
@@ -490,7 +498,7 @@ class Legend_Dialog(wx.Dialog):
         # color change button, opens a new color dialog
         button = wx.Button(self, ID_COLOR_CHANGE, _("Change Color"))
         button.SetFocus()
-        EVT_BUTTON(self, ID_COLOR_CHANGE, self.OnChangeColor)
+        wx.EVT_BUTTON(self, ID_COLOR_CHANGE, self.OnChangeColor)
         box_color.Add(button, 1, wx.EXPAND|wx.ALL, 5)
 
         # status
@@ -517,7 +525,7 @@ class Legend_Dialog(wx.Dialog):
         
         # button for label
         labelbutton = wx.Button(self, ID_LABEL_CHANGE, _("Change Label"))
-        EVT_BUTTON(self, ID_LABEL_CHANGE, self.OnChangeLabel)
+        wx.EVT_BUTTON(self, ID_LABEL_CHANGE, self.OnChangeLabel)
         
         #buttons
         box_buttons = wx.BoxSizer(wx.HORIZONTAL)
@@ -526,8 +534,8 @@ class Legend_Dialog(wx.Dialog):
         button = wx.Button(self, wx.ID_CANCEL, _("Cancel"))
         box_buttons.Add(button, 0, wx.ALL, 5)
         #set the button funcitons
-        EVT_BUTTON(self, wx.ID_OK, self.OnOK)
-        EVT_BUTTON(self, wx.ID_CANCEL, self.OnCancel)        
+        wx.EVT_BUTTON(self, wx.ID_OK, self.OnOK)
+        wx.EVT_BUTTON(self, wx.ID_CANCEL, self.OnCancel)        
         
         # compose the final layout
         top = wx.BoxSizer(wx.VERTICAL)
@@ -638,7 +646,7 @@ class Label_Dialog(wx.Dialog):
         # color change button, opens a new color dialog
         button = wx.Button(self, ID_COLOR_CHANGE, _("Change Color"))
         button.SetFocus()
-        EVT_BUTTON(self, ID_COLOR_CHANGE, self.OnChangeColor)
+        wx.EVT_BUTTON(self, ID_COLOR_CHANGE, self.OnChangeColor)
         box_color.Add(button, 1, wx.EXPAND|wx.ALL, 5)
 
         #get the set type
@@ -750,8 +758,8 @@ class Label_Dialog(wx.Dialog):
         button = wx.Button(self, wx.ID_CANCEL, _("Cancel"))
         box_buttons.Add(button, 0, wx.ALL, 5)
         #set the button funcitons
-        EVT_BUTTON(self, wx.ID_OK, self.OnOK)
-        EVT_BUTTON(self, wx.ID_CANCEL, self.OnCancel)        
+        wx.EVT_BUTTON(self, wx.ID_OK, self.OnOK)
+        wx.EVT_BUTTON(self, wx.ID_CANCEL, self.OnCancel)        
         
         # compose the Dialog
         top = wx.BoxSizer(wx.VERTICAL)
@@ -864,7 +872,7 @@ class Scalebar_Dialog(wx.Dialog):
         # color change button, opens a new color dialog
         button = wx.Button(self, ID_COLOR_CHANGE, _("Change Color"))
         button.SetFocus()
-        EVT_BUTTON(self, ID_COLOR_CHANGE, self.OnChangeColor)
+        wx.EVT_BUTTON(self, ID_COLOR_CHANGE, self.OnChangeColor)
         box_color.Add(button, 1, wx.EXPAND|wx.ALL, 5)
         # show the two color chooser horizontal
         colorHor = wx.BoxSizer(wx.HORIZONTAL)
@@ -884,7 +892,7 @@ class Scalebar_Dialog(wx.Dialog):
         # color change button, opens a new color dialog
         button = wx.Button(self, ID_IMGCOLOR_CHANGE, _("Change ImageColor"))
         button.SetFocus()
-        EVT_BUTTON(self, ID_IMGCOLOR_CHANGE, self.OnChangeImageColor)
+        wx.EVT_BUTTON(self, ID_IMGCOLOR_CHANGE, self.OnChangeImageColor)
         box_imgcolor.Add(button, 1, wx.EXPAND|wx.ALL, 5)
         colorHor.Add(box_imgcolor,0, wx.EXPAND |wx.ALL, 5)
         
@@ -969,7 +977,7 @@ class Scalebar_Dialog(wx.Dialog):
         
         # button for label
         labelbutton = wx.Button(self, ID_LABEL_CHANGE, _("Change Label"))
-        EVT_BUTTON(self, ID_LABEL_CHANGE, self.OnChangeLabel)
+        wx.EVT_BUTTON(self, ID_LABEL_CHANGE, self.OnChangeLabel)
         
         #buttons
         box_buttons = wx.BoxSizer(wx.HORIZONTAL)
@@ -979,8 +987,8 @@ class Scalebar_Dialog(wx.Dialog):
         button.SetFocus()
         box_buttons.Add(button, 0, wx.ALL, 5)
         #set the button funcitons
-        EVT_BUTTON(self, wx.ID_OK, self.OnOK)
-        EVT_BUTTON(self, wx.ID_CANCEL, self.OnCancel)      
+        wx.EVT_BUTTON(self, wx.ID_OK, self.OnOK)
+        wx.EVT_BUTTON(self, wx.ID_CANCEL, self.OnCancel)      
       
         # compose the dialog
         top = wx.BoxSizer(wx.VERTICAL)
@@ -1086,11 +1094,11 @@ class Metadata_CustomDataTable(grid.PyGridTableBase):
     copied from the wx. demo.
     """
     def __init__(self, data):
-        gridPyGridTableBase.__init__(self)
+        grid.PyGridTableBase.__init__(self)
 
         self.colLabels = ['ID', 'Description']
-        self.dataTypes = [wx.GRID_VALUE_STRING,
-                          wx.GRID_VALUE_STRING
+        self.dataTypes = [grid.GRID_VALUE_STRING,
+                          grid.GRID_VALUE_STRING
                           ]
         
         if data:
@@ -1109,7 +1117,7 @@ class Metadata_CustomDataTable(grid.PyGridTableBase):
         try:
             return not self.data[row][col]
         except IndexError:
-            return true
+            return True
 
     # Get/Set values in the table.  The Python version of these
     # methods can handle any data-type, (as long as the Editor and
@@ -1132,7 +1140,7 @@ class Metadata_CustomDataTable(grid.PyGridTableBase):
 
             # tell the grid we've added a row
             msg = grid.GridTableMessage(self,                             # The table
-                                     wx.GRIDTABLE_NOTIFY_ROWS_APPENDED, # what we did to it
+                                     grid.GRIDTABLE_NOTIFY_ROWS_APPENDED, # what we did to it
                                      1)                                # how many
 
             self.GetView().ProcessTableMessage(msg)
@@ -1156,7 +1164,7 @@ class Metadata_CustomDataTable(grid.PyGridTableBase):
     def CanGetValueAs(self, row, col, typeName):
         colType = self.dataTypes[col].split(':')[0]
         if typeName == colType:
-            return true
+            return True
         else:
             return False
 
@@ -1173,7 +1181,7 @@ class Metadata_TableGrid(grid.Grid):
         # The second parameter means that the grid is to take ownership of the
         # table and will destroy it when done.  Otherwise you would need to keep
         # a reference to it and call it's Destroy method later.
-        self.SetTable(self.table, true)
+        self.SetTable(self.table, True)
 
         self.SetRowLabelSize(0)
         self.SetColMinimalWidth(0,180)
@@ -1181,7 +1189,7 @@ class Metadata_TableGrid(grid.Grid):
         self.SetColMinimalWidth(1,250)
         self.SetColSize(1,250)
         self.SetMargins(0,0)
-        EVT_GRID_CELL_LEFT_DCLICK(self, self.OnLeftDClick)
+        grid.EVT_GRID_CELL_LEFT_DCLICK(self, self.OnLeftDClick)
 
     def get_table(self):
         return self.table
@@ -1221,8 +1229,8 @@ class Metadata_Dialog(wx.Dialog):
         button.SetFocus()
         box_buttons.Add(button, 0, wx.ALL, 5)
         #set the button funcitons
-        EVT_BUTTON(self, wx.ID_OK, self.OnOK)
-        EVT_BUTTON(self, wx.ID_CANCEL, self.OnCancel)      
+        wx.EVT_BUTTON(self, wx.ID_OK, self.OnOK)
+        wx.EVT_BUTTON(self, wx.ID_CANCEL, self.OnCancel)      
         
         # compose the dialog
         top = wx.BoxSizer(wx.VERTICAL)
@@ -1376,7 +1384,7 @@ mapserver_edit_menu.InsertItem("Web Settings")
 # register the new command (Layer Settings Dialog)
 registry.Add(Command("Layer Settings", _("Layer"),
                      layersettings,
-                     helptext = _("Edit the Layer Setting of the aktive Layer"), \
+                     helptext = _("Edit the Layer Setting of the active Layer"), \
                      sensitive = _has_umn_mapobj_and_selectedlayer))
 # finally add the new entry to the extensions menu
 mapserver_edit_menu.InsertItem("Layer Settings")
