@@ -7,9 +7,9 @@
 
 """The Classification Generator Dialog"""
 
-__version__ = "$Revision: 2709 $"
+__version__ = "$Revision: 2883 $"
 # $Source$
-# $Id: classgen.py 2709 2006-10-03 09:34:51Z dpinte $
+# $Id: classgen.py 2883 2009-08-12 23:21:12Z dpinte $
 
 
 import sys
@@ -25,6 +25,7 @@ from Thuban.Model.table import FIELDTYPE_INT, FIELDTYPE_DOUBLE, \
 
 from Thuban.Model.layer import SHAPETYPE_ARC
 from Thuban.Model.range import Range
+from Thuban.UI import internal_from_wxstring
 from Thuban.UI.common import ThubanBeginBusyCursor, ThubanEndBusyCursor
 
 import classifier, resource
@@ -87,8 +88,8 @@ class ClassGenDialog(wx.Dialog):
         # we need to create genButton first because when we create the
         # panels they will call AllowGenerate() which uses genButton.
         #
-        self.genButton = wx.Button(self, wx.ID_OK, _("Generate"))
-        self.cancelButton = wx.Button(self, wx.ID_CANCEL, _("Close"))
+        self.genButton = wx.Button(self, wx.NewId(), _("Generate"))
+        self.cancelButton = wx.Button(self, wx.NewId(), _("Close"))
         self.genButton.SetDefault()
 
         self.genChoice = wx.Choice(self, ID_CLASSGEN_GENCOMBO)
@@ -213,7 +214,7 @@ class ClassGenDialog(wx.Dialog):
 
         assert index != -1, "button should be disabled!"
 
-        genSel = self.genChoice.GetString(index)
+        genSel = internal_from_wxstring(self.genChoice.GetString(index))
         clazz, genPanel = self.genChoice.GetClientData(index)
 
         propPanel = self.propPanel
@@ -226,7 +227,6 @@ class ClassGenDialog(wx.Dialog):
 
             index = self.propCombo.GetSelection()
 
-            propSel = self.propCombo.GetString(index)
             propPanel = self.propCombo.GetClientData(index)
 
             ramp = propPanel.GetRamp()
@@ -310,7 +310,6 @@ class ClassGenDialog(wx.Dialog):
         combo = event.GetEventObject()
 
         selIndex = combo.GetSelection()
-        sel = combo.GetString(selIndex)
 
         if isinstance(self.propPanel, wx.Panel):
             self.topBox.Show(self.propPanel, False)
@@ -410,7 +409,7 @@ class GenUniformPanel(wx.Panel):
         self.numGroupsChanging = False
         self.steppingChanging = False
 
-        self.numGroupsCtrl.SetRange(1, sys.maxint)
+        self.numGroupsCtrl.SetRange(1, 2**31-1)
 
         self.numGroupsCtrl.SetValue(1)
         self.stepCtrl.SetValue("1")
@@ -795,6 +794,7 @@ class GenUniquePanel(wx.Panel):
 
     def __MoveListItem(self, index, list_src, list_dest):
 
+        # The following code is neutral regarding the type of the "String"s.
         item = list_src.GetItem(index)
 
         x = list_dest.InsertStringItem(
@@ -832,7 +832,7 @@ class GenQuantilesPanel(wx.Panel):
                                         _("Retrieve from Table"))
 
         self.spin_numClasses = wx.SpinCtrl(self, -1, style=wx.TE_RIGHT)
-        self.spin_numClasses.SetRange(2, sys.maxint)
+        self.spin_numClasses.SetRange(2, 2**31-1)
         self.spin_numClasses.SetValue(2)
 
 
