@@ -9,9 +9,9 @@
 
 """Projection dialog"""
 
-__version__ = "$Revision: 2700 $"
+__version__ = "$Revision: 2882 $"
 # $Source$
-# $Id: projdialog.py 2700 2006-09-18 14:27:02Z dpinte $
+# $Id: projdialog.py 2882 2009-08-12 23:14:29Z dpinte $
 
 import sys, os
 import wx
@@ -24,6 +24,7 @@ from Thuban.Model.resource import get_user_proj_file, get_system_proj_file, \
                                   read_proj_file, write_proj_file, \
                                   DEFAULT_PROJ_FILE, EPSG_PROJ_FILE, \
                                   EPSG_DEPRECATED_PROJ_FILE
+from Thuban.UI import internal_from_wxstring
 from Thuban.UI.dialogs import NonModalNonParentDialog
 
 from common import ThubanBeginBusyCursor, ThubanEndBusyCursor
@@ -307,14 +308,14 @@ class ProjFrame(NonModalNonParentDialog):
                 self.parent.application.Path("projection"), style = wx.OPEN)
 
         if dlg.ShowModal() == wx.ID_OK:
-            path = dlg.GetPath()
+            path = internal_from_wxstring(dlg.GetPath())
 
             ThubanBeginBusyCursor()
             try:
                 try:
                     projFile, warnings = read_proj_file(path)
                 except IOError, (errno, errstr):
-                    self.__ShowError(dlg.GetPath(), errstr)
+                    self.__ShowError(path, errstr)
                 else:
                     self.show_warnings(_("Warnings"), path, warnings)
                     for proj in projFile.GetProjections():
@@ -339,12 +340,13 @@ class ProjFrame(NonModalNonParentDialog):
                 style=wx.SAVE|wx.OVERWRITE_PROMPT)
 
         if dlg.ShowModal() == wx.ID_OK:
-            proj_file = ProjFile(dlg.GetPath())
+            path = internal_from_wxstring(dlg.GetPath())
+            proj_file = ProjFile(path)
             for proj, pf in sel:
                 if proj is not None:
                     proj_file.Add(proj)
             self.write_proj_file(proj_file)
-            self.parent.application.SetPath("projection", dlg.GetPath())
+            self.parent.application.SetPath("projection", path)
 
         dlg.Destroy()
 
@@ -573,7 +575,11 @@ class ProjFrame(NonModalNonParentDialog):
         # self.curProjPanel should always contain the most relevant data
         # for a projection
         if self.curProjPanel is not None:
-            parameters = self.curProjPanel.GetParameters()
+            # remove internal_from_wxstring call in profit of a str call
+            # Projection parameters must be str (otherwise swig does not treat them as is)
+            # this is kind of "works for me". I did not took time to investigate the real issue with internal_from_wxstring
+            parameters = \
+                map(str,self.curProjPanel.GetParameters())
             if parameters is not None:
                 return Projection(parameters, self.projname.GetValue())
 
@@ -803,7 +809,6 @@ class TMPanel(ProjPanel):
         self.__falseNorth.Clear()
         self.__scale.Clear()
 
-        ProjPanel.Clear(self)
 
 ID_UTMPANEL_ZONE = 4001
 ID_UTMPANEL_SOUTH = 4002
@@ -857,7 +862,6 @@ class UTMPanel(ProjPanel):
     def Clear(self):
         self.__zone.SetValue(1)
         self.__south.SetValue(False)
-        ProjPanel.Clear(self)
 
     def _OnPropose(self, event):
         """Call the propose dialog.
@@ -947,7 +951,6 @@ class LCCPanel(ProjPanel):
         self.__falseEast.Clear()
         self.__falseNorth.Clear()
 
-        ProjPanel.Clear(self)
 
 class GeoPanel(ProjPanel):
     """Projection Panel for a Geographic Projection."""
@@ -984,7 +987,7 @@ class GeoPanel(ProjPanel):
         return params
 
     def Clear(self):
-        ProjPanel.Clear(self)
+        pass
 
     def _DoLayout(self):
         sizer = wx.BoxSizer(wx.HORIZONTAL)
