@@ -10,6 +10,9 @@
 import sys, os
 import Thuban
 
+import wxversion
+wxversion.select("2.8")
+
 # Put the Lib dir into the path. The Lib dir contains some extra non
 # really Thuban specific Python modules
 thubandir = os.path.join(Thuban.__path__[0], '..')
@@ -30,8 +33,7 @@ if sys.platform == 'win32':
         print "Please update your PATH environment variable to include %s\\gdal\\bin" % thubandir
 
 import Thuban.UI.main
-    
+
 # Start Thuban
-Thuban.UI.main.main()
-
-
+if __name__ == "__main__":
+    Thuban.UI.main.main()
